@@ -1,31 +1,17 @@
 # -*- coding: utf-8 -*-
-"""
-    Copyright (C) 2013, 2014 Kouhei Maeda <mkouhei@palmtb.net>
-
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""
+"""backup2swift.command module."""
 import argparse
 import os
 import os.path
 import sys
+from swiftsc.exception import AuthenticationError
 from backup2swift import __version__, backup, utils, config
 
 DEFAULT_CONF = '.bu2sw.conf'
 
 
 def parse_options():
-    """ setup options. """
+    """setup options."""
     parser = argparse.ArgumentParser(description='usage')
     setoption(parser, 'version')
     setoption(parser, 'config')
@@ -36,7 +22,8 @@ def parse_options():
 
 
 def setoption(parser, keyword):
-    """
+    """Set option of argument parser.
+
     Arguments:
         parser: object of argparse
         keyword: switching keyword
@@ -72,7 +59,7 @@ def setoption(parser, keyword):
 
 
 def check_config_file(args_config):
-    """
+    """Check configuration file.
 
     Argument:
         args_config: args.config
@@ -80,9 +67,9 @@ def check_config_file(args_config):
     if args_config:
         # override configuration file path
         config_file = args_config
-    elif os.path.isfile(os.path.join(os.environ['HOME'], DEFAULT_CONF)):
+    elif os.path.isfile(os.path.join(os.path.expanduser('~'), DEFAULT_CONF)):
         # use default configuration file
-        config_file = os.path.join(os.environ['HOME'], DEFAULT_CONF)
+        config_file = os.path.join(os.path.expanduser('~'), DEFAULT_CONF)
     else:
         raise IOError(('Setup "~/.bu2sw.conf" or '
                        'specify configuration file with "-c" option'))
@@ -90,7 +77,7 @@ def check_config_file(args_config):
 
 
 def execute_swift_client(args):
-    """
+    """Execute swift client.
 
     Argument:
         args: argument object
@@ -132,11 +119,11 @@ def execute_swift_client(args):
 
 
 def main():
-    """ main function """
+    """main function."""
     try:
         args = parse_options()
         args.func(args)
-    except (RuntimeError, IOError) as error:
+    except (RuntimeError, IOError, AuthenticationError) as error:
         # syslog.ERR is 3
         utils.logging(3, error)
 
