@@ -1,31 +1,16 @@
 # -*- coding: utf-8 -*-
-"""
-    Copyright (C) 2013, 2014 Kouhei Maeda <mkouhei@palmtb.net>
-
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""
+""" backup2swift.tests.test_command """
 import unittest
 import os
 import argparse
 import sys
+from backup2swift import __version__
+from backup2swift import command as c
+from backup2swift.tests import test_vars as v
 if sys.version_info < (3, 0):
     from StringIO import StringIO
 else:
     from io import StringIO
-from backup2swift import __version__
-from backup2swift import command as c
-from backup2swift.tests import test_vars as v
 
 
 class CommandTests(unittest.TestCase):
@@ -43,6 +28,8 @@ class CommandTests(unittest.TestCase):
         """ finalize """
         sys.stdout = self.capture
         sys.stderr = self.capture_err
+        if os.path.isfile('dummy'):
+            os.remove('dummy')
 
     def test_check_config_file(self):
         """ unit test for check_config_file """
@@ -51,7 +38,8 @@ class CommandTests(unittest.TestCase):
 
     def test_check_config_file_fail(self):
         """ unit test for check_config_file fail case """
-        if not os.path.isfile(os.path.join(os.environ['HOME'], '.bu2sw.conf')):
+        if not os.path.isfile(os.path.join(os.path.expanduser('~'),
+                                           '.bu2sw.conf')):
             self.assertRaises(IOError, c.check_config_file, None)
 
     def test_parse_options(self):
