@@ -1,20 +1,5 @@
 # -*- coding: utf-8 -*-
-"""
-    Copyright (C) 2013, 2014 Kouhei Maeda <mkouhei@palmtb.net>
-
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""
+""" backup2swift.tests.test_config """
 import unittest
 from backup2swift import config as c
 
@@ -27,7 +12,7 @@ class ConfigTests(unittest.TestCase):
         self.assertEqual(('https://example.org/auth/v1.0',
                           'username',
                           'password',
-                          '10',
+                          10,
                           True,
                           5.0,
                           None),
@@ -38,7 +23,7 @@ class ConfigTests(unittest.TestCase):
         self.assertEqual(('https://example.org/auth/v1.0',
                           'username',
                           'password',
-                          '10',
+                          10,
                           False,
                           5.0,
                           None),
@@ -49,7 +34,7 @@ class ConfigTests(unittest.TestCase):
         self.assertEqual(('https://example.org/auth/v1.0',
                           'username',
                           'password',
-                          '10',
+                          10,
                           True,
                           10.0,
                           None),
