@@ -1,28 +1,13 @@
 # -*- coding: utf-8 -*-
-"""
-    Copyright (C) 2013, 2014 Kouhei Maeda <mkouhei@palmtb.net>
-
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""
+""" backup2swift.tests.test_utils """
 import unittest
 import sys
+from backup2swift import utils as u
+from backup2swift.tests import test_vars as v
 if sys.version_info < (3, 0):
     from StringIO import StringIO
 else:
     from io import StringIO
-from backup2swift import utils as u
-from backup2swift.tests import test_vars as v
 
 
 class UtilsTests(unittest.TestCase):
